==> state-use-6.0.8.tgz: package/lib/cjs/index.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

require("core-js/modules/es.object.to-string.js");

require("core-js/modules/es.promise.js");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _reactHooks = require("@testing-library/react-hooks");

var _index = require("./index");

var async = {
  default: function _default() {
    return {
      state: 'default'
    };
  },
  loading: function loading() {
    return {
      state: 'loading'
    };
  },
  success: function success(r) {
    return {
      state: 'success',
      response: r
    };
  },
  failure: function failure(e) {
    return {
      state: 'failure',
      error: e
    };
  }
};
test('should update', function () {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });

  var _renderHook = (0, _reactHooks.renderHook)(function (props) {
    return state.use(function (s) {
      return s.a + props.delta;
    }, [props.delta]);
  }, {
    initialProps: {
      delta: 1
    }
  }),
      result = _renderHook.result,
      rerender = _renderHook.rerender; // update state.


  (0, _reactHooks.act)(function () {
    state.update(function (ctx) {
      ctx.state.a++;
    });
    state.update(function (ctx) {
      ctx.state.a++;
    });
  });
  expect(result.current).toBe(4);
  expect(result.all).toHaveLength(2); // update deps.

  rerender({
    delta: 2
  });
  expect(result.current).toBe(5);
  expect(result.all).toHaveLength(3);
});
test('shouldn\'t update', function () {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });

  var _renderHook2 = (0, _reactHooks.renderHook)(function (props) {
    return state.use(function (s) {
      return [s.a + props.delta];
    }, [props.delta]);
  }, {
    initialProps: {
      delta: 1
    }
  }),
      result = _renderHook2.result,
      rerender = _renderHook2.rerender; // no change state.


  var current = result.current;
  (0, _reactHooks.act)(function () {
    state.update(function (ctx) {
      ctx.state.a = 1;
    });
  });
  expect(result.current).toBe(current);
  expect(result.all).toHaveLength(1); // no change deps.

  rerender({
    delta: 1
  });
  expect(result.current).toBe(current);
  expect(result.all).toHaveLength(2);
});
test('async success', /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee3() {
  var state, _renderHook3, result;

  return _regenerator.default.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          state = (0, _index.define)();
          state.setup({
            num: async.default()
          });
          _renderHook3 = (0, _reactHooks.renderHook)(function () {
            return state.use(function (s) {
              return s;
            });
          }), result = _renderHook3.result;
          _context3.next = 5;
          return (0, _reactHooks.act)( /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee2() {
            return _regenerator.default.wrap(function _callee2$(_context2) {
              while (1) {
                switch (_context2.prev = _context2.next) {
                  case 0:
                    _context2.next = 2;
                    return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee(ctx) {
                      return _regenerator.default.wrap(function _callee$(_context) {
                        while (1) {
                          switch (_context.prev = _context.next) {
                            case 0:
                              ctx.state.num = async.loading();
                              _context.prev = 1;
                              _context.t0 = async;
                              _context.next = 5;
                              return wait(100).then(function () {
                                return 100;
                              });

                            case 5:
                              _context.t1 = _context.sent;
                              ctx.state.num = _context.t0.success.call(_context.t0, _context.t1);
                              _context.next = 12;
                              break;

                            case 9:
                              _context.prev = 9;
                              _context.t2 = _context["catch"](1);
                              ctx.state.num = async.failure(_context.t2);

                            case 12:
                            case "end":
                              return _context.stop();
                          }
                        }
                      }, _callee, null, [[1, 9]]);
                    }));

                  case 2:
                  case "end":
                    return _context2.stop();
                }
              }
            }, _callee2);
          })));

        case 5:
          expect(result.all).toEqual([{
            num: async.default()
          }, {
            num: async.loading()
          }, {
            num: async.success(100)
          }]);

        case 6:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3);
})));
test('async failure', /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee6() {
  var state, _renderHook4, result;

  return _regenerator.default.wrap(function _callee6$(_context6) {
    while (1) {
      switch (_context6.prev = _context6.next) {
        case 0:
          state = (0, _index.define)();
          state.setup({
            num: async.default()
          });
          _renderHook4 = (0, _reactHooks.renderHook)(function () {
            return state.use(function (s) {
              return s;
            });
          }), result = _renderHook4.result;
          _context6.next = 5;
          return (0, _reactHooks.act)( /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee5() {
            return _regenerator.default.wrap(function _callee5$(_context5) {
              while (1) {
                switch (_context5.prev = _context5.next) {
                  case 0:
                    _context5.next = 2;
                    return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee4(ctx) {
                      return _regenerator.default.wrap(function _callee4$(_context4) {
                        while (1) {
                          switch (_context4.prev = _context4.next) {
                            case 0:
                              ctx.state.num = async.loading();
                              _context4.prev = 1;
                              _context4.t0 = async;
                              _context4.next = 5;
                              return wait(100).then(function () {
                                return Promise.reject(100);
                              });

                            case 5:
                              _context4.t1 = _context4.sent;
                              ctx.state.num = _context4.t0.success.call(_context4.t0, _context4.t1);
                              _context4.next = 12;
                              break;

                            case 9:
                              _context4.prev = 9;
                              _context4.t2 = _context4["catch"](1);
                              ctx.state.num = async.failure(_context4.t2);

                            case 12:
                            case "end":
                              return _context4.stop();
                          }
                        }
                      }, _callee4, null, [[1, 9]]);
                    }));

                  case 2:
                  case "end":
                    return _context5.stop();
                }
              }
            }, _callee5);
          })));

        case 5:
          expect(result.all).toEqual([{
            num: async.default()
          }, {
            num: async.loading()
          }, {
            num: async.failure(100)
          }]);

        case 6:
        case "end":
          return _context6.stop();
      }
    }
  }, _callee6);
})));
test('nested update', function () {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });

  var _renderHook5 = (0, _reactHooks.renderHook)(function () {
    return state.use(function (s) {
      return s.a;
    });
  }),
      result = _renderHook5.result;

  (0, _reactHooks.act)(function () {
    state.update(function (ctx) {
      ctx.state.a++;
      state.update(function (ctx) {
        ctx.state.a++;
      });
    });
  });
  expect(result.current).toEqual(3);
  expect(result.all).toHaveLength(2);
});
test('merge synchronous context', function () {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });

  var _renderHook6 = (0, _reactHooks.renderHook)(function () {
    return state.use(function (s) {
      return s.a;
    });
  }),
      result = _renderHook6.result;

  (0, _reactHooks.act)(function () {
    state.update(function (ctx) {
      var s = ctx.state;
      state.update(function () {
        s.a++;
      });
      s.a++;
    });
  });
  expect(result.current).toEqual(3);
  expect(result.all).toHaveLength(2);
});
test('merge synchronous context after async', /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee9() {
  var state, _renderHook7, result;

  return _regenerator.default.wrap(function _callee9$(_context9) {
    while (1) {
      switch (_context9.prev = _context9.next) {
        case 0:
          state = (0, _index.define)();
          state.setup({
            a: 1
          });
          _renderHook7 = (0, _reactHooks.renderHook)(function () {
            return state.use(function (s) {
              return s.a;
            });
          }), result = _renderHook7.result;
          _context9.next = 5;
          return (0, _reactHooks.act)( /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee8() {
            return _regenerator.default.wrap(function _callee8$(_context8) {
              while (1) {
                switch (_context8.prev = _context8.next) {
                  case 0:
                    _context8.next = 2;
                    return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee7(ctx) {
                      var s;
                      return _regenerator.default.wrap(function _callee7$(_context7) {
                        while (1) {
                          switch (_context7.prev = _context7.next) {
                            case 0:
                              ctx.state.a = 2;
                              _context7.next = 3;
                              return wait(100).then(function () {
                                return Promise.resolve(100);
                              });

                            case 3:
                              ctx.state.a = _context7.sent;
                              s = ctx.state;
                              state.update(function () {
                                s.a++;
                              });
                              s.a++;

                            case 7:
                            case "end":
                              return _context7.stop();
                          }
                        }
                      }, _callee7);
                    }));

                  case 2:
                  case "end":
                    return _context8.stop();
                }
              }
            }, _callee8);
          })));

        case 5:
          expect(result.current).toEqual(102);
          expect(result.all).toHaveLength(3);

        case 7:
        case "end":
          return _context9.stop();
      }
    }
  }, _callee9);
})));
test('nested async update', /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee13() {
  var state, _renderHook8, result;

  return _regenerator.default.wrap(function _callee13$(_context13) {
    while (1) {
      switch (_context13.prev = _context13.next) {
        case 0:
          state = (0, _index.define)();
          state.setup({
            a: 1
          });
          _renderHook8 = (0, _reactHooks.renderHook)(function () {
            return state.use(function (s) {
              return s.a;
            });
          }), result = _renderHook8.result;
          _context13.next = 5;
          return (0, _reactHooks.act)( /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee12() {
            return _regenerator.default.wrap(function _callee12$(_context12) {
              while (1) {
                switch (_context12.prev = _context12.next) {
                  case 0:
                    _context12.next = 2;
                    return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee11(ctx) {
                      return _regenerator.default.wrap(function _callee11$(_context11) {
                        while (1) {
                          switch (_context11.prev = _context11.next) {
                            case 0:
                              ctx.state.a++;
                              _context11.next = 3;
                              return wait(100).then(function () {
                                return ctx.state.a + 1;
                              });

                            case 3:
                              ctx.state.a = _context11.sent;
                              _context11.next = 6;
                              return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee10(ctx) {
                                return _regenerator.default.wrap(function _callee10$(_context10) {
                                  while (1) {
                                    switch (_context10.prev = _context10.next) {
                                      case 0:
                                        ctx.state.a++;
                                        _context10.next = 3;
                                        return wait(100).then(function () {
                                          return ctx.state.a + 1;
                                        });

                                      case 3:
                                        ctx.state.a = _context10.sent;
                                        state.update(function (ctx) {
                                          ctx.state.a++;
                                        });

                                      case 5:
                                      case "end":
                                        return _context10.stop();
                                    }
                                  }
                                }, _callee10);
                              }));

                            case 6:
                            case "end":
                              return _context11.stop();
                          }
                        }
                      }, _callee11);
                    }));

                  case 2:
                  case "end":
                    return _context12.stop();
                }
              }
            }, _callee12);
          })));

        case 5:
          expect(result.all).toEqual([1, 2, 4, 6]);

        case 6:
        case "end":
          return _context13.stop();
      }
    }
  }, _callee13);
})));
test('revoked draft should raise error', function (done) {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });
  state.update(function (ctx) {
    var draft = ctx.state;
    draft.a++;
    setTimeout(function () {
      expect(function () {
        draft.a++;
      }).toThrow();
      done();
    }, 100);
  });
});

var wait = function wait(timeout) {
  return new Promise(function (resolve) {
    return setTimeout(resolve, timeout);
  });
};

==> state-use-6.0.9.tgz: package/lib/cjs/index.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

require("core-js/modules/es.object.to-string.js");

require("core-js/modules/es.promise.js");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _reactHooks = require("@testing-library/react-hooks");

var _index = require("./index");

var async = {
  default: function _default() {
    return {
      state: 'default'
    };
  },
  loading: function loading() {
    return {
      state: 'loading'
    };
  },
  success: function success(r) {
    return {
      state: 'success',
      response: r
    };
  },
  failure: function failure(e) {
    return {
      state: 'failure',
      error: e
    };
  }
};
test('re-setup', function () {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });

  var _renderHook = (0, _reactHooks.renderHook)(function () {
    return state.use(function (s) {
      return s.a;
    });
  }),
      result = _renderHook.result; // update state.


  (0, _reactHooks.act)(function () {
    state.setup({
      a: 2
    });
  });
  expect(result.current).toBe(2);
  expect(result.all).toHaveLength(2);
});
test('should update', function () {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });

  var _renderHook2 = (0, _reactHooks.renderHook)(function (props) {
    return state.use(function (s) {
      return s.a + props.delta;
    }, [props.delta]);
  }, {
    initialProps: {
      delta: 1
    }
  }),
      result = _renderHook2.result,
      rerender = _renderHook2.rerender; // update state.


  (0, _reactHooks.act)(function () {
    state.update(function (ctx) {
      ctx.state.a++;
    });
    state.update(function (ctx) {
      ctx.state.a++;
    });
  });
  expect(result.current).toBe(4);
  expect(result.all).toHaveLength(2); // update deps.

  rerender({
    delta: 2
  });
  expect(result.current).toBe(5);
  expect(result.all).toHaveLength(3);
});
test('shouldn\'t update', function () {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });

  var _renderHook3 = (0, _reactHooks.renderHook)(function (props) {
    return state.use(function (s) {
      return [s.a + props.delta];
    }, [props.delta]);
  }, {
    initialProps: {
      delta: 1
    }
  }),
      result = _renderHook3.result,
      rerender = _renderHook3.rerender; // no change state.


  var current = result.current;
  (0, _reactHooks.act)(function () {
    state.update(function (ctx) {
      ctx.state.a = 1;
    });
  });
  expect(result.current).toBe(current);
  expect(result.all).toHaveLength(1); // no change deps.

  rerender({
    delta: 1
  });
  expect(result.current).toBe(current);
  expect(result.all).toHaveLength(2);
});
test('async success', /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee3() {
  var state, _renderHook4, result;

  return _regenerator.default.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          state = (0, _index.define)();
          state.setup({
            num: async.default()
          });
          _renderHook4 = (0, _reactHooks.renderHook)(function () {
            return state.use(function (s) {
              return s;
            });
          }), result = _renderHook4.result;
          _context3.next = 5;
          return (0, _reactHooks.act)( /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee2() {
            return _regenerator.default.wrap(function _callee2$(_context2) {
              while (1) {
                switch (_context2.prev = _context2.next) {
                  case 0:
                    _context2.next = 2;
                    return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee(ctx) {
                      return _regenerator.default.wrap(function _callee$(_context) {
                        while (1) {
                          switch (_context.prev = _context.next) {
                            case 0:
                              ctx.state.num = async.loading();
                              _context.prev = 1;
                              _context.t0 = async;
                              _context.next = 5;
                              return wait(100).then(function () {
                                return 100;
                              });

                            case 5:
                              _context.t1 = _context.sent;
                              ctx.state.num = _context.t0.success.call(_context.t0, _context.t1);
                              _context.next = 12;
                              break;

                            case 9:
                              _context.prev = 9;
                              _context.t2 = _context["catch"](1);
                              ctx.state.num = async.failure(_context.t2);

                            case 12:
                            case "end":
                              return _context.stop();
                          }
                        }
                      }, _callee, null, [[1, 9]]);
                    }));

                  case 2:
                  case "end":
                    return _context2.stop();
                }
              }
            }, _callee2);
          })));

        case 5:
          expect(result.all).toEqual([{
            num: async.default()
          }, {
            num: async.loading()
          }, {
            num: async.success(100)
          }]);

        case 6:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3);
})));
test('async failure', /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee6() {
  var state, _renderHook5, result;

  return _regenerator.default.wrap(function _callee6$(_context6) {
    while (1) {
      switch (_context6.prev = _context6.next) {
        case 0:
          state = (0, _index.define)();
          state.setup({
            num: async.default()
          });
          _renderHook5 = (0, _reactHooks.renderHook)(function () {
            return state.use(function (s) {
              return s;
            });
          }), result = _renderHook5.result;
          _context6.next = 5;
          return (0, _reactHooks.act)( /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee5() {
            return _regenerator.default.wrap(function _callee5$(_context5) {
              while (1) {
                switch (_context5.prev = _context5.next) {
                  case 0:
                    _context5.next = 2;
                    return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee4(ctx) {
                      return _regenerator.default.wrap(function _callee4$(_context4) {
                        while (1) {
                          switch (_context4.prev = _context4.next) {
                            case 0:
                              ctx.state.num = async.loading();
                              _context4.prev = 1;
                              _context4.t0 = async;
                              _context4.next = 5;
                              return wait(100).then(function () {
                                return Promise.reject(100);
                              });

                            case 5:
                              _context4.t1 = _context4.sent;
                              ctx.state.num = _context4.t0.success.call(_context4.t0, _context4.t1);
                              _context4.next = 12;
                              break;

                            case 9:
                              _context4.prev = 9;
                              _context4.t2 = _context4["catch"](1);
                              ctx.state.num = async.failure(_context4.t2);

                            case 12:
                            case "end":
                              return _context4.stop();
                          }
                        }
                      }, _callee4, null, [[1, 9]]);
                    }));

                  case 2:
                  case "end":
                    return _context5.stop();
                }
              }
            }, _callee5);
          })));

        case 5:
          expect(result.all).toEqual([{
            num: async.default()
          }, {
            num: async.loading()
          }, {
            num: async.failure(100)
          }]);

        case 6:
        case "end":
          return _context6.stop();
      }
    }
  }, _callee6);
})));
test('nested update', function () {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });

  var _renderHook6 = (0, _reactHooks.renderHook)(function () {
    return state.use(function (s) {
      return s.a;
    });
  }),
      result = _renderHook6.result;

  (0, _reactHooks.act)(function () {
    state.update(function (ctx) {
      ctx.state.a++;
      state.update(function (ctx) {
        ctx.state.a++;
      });
    });
  });
  expect(result.current).toEqual(3);
  expect(result.all).toHaveLength(2);
});
test('merge synchronous context', function () {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });

  var _renderHook7 = (0, _reactHooks.renderHook)(function () {
    return state.use(function (s) {
      return s.a;
    });
  }),
      result = _renderHook7.result;

  (0, _reactHooks.act)(function () {
    state.update(function (ctx) {
      var s = ctx.state;
      state.update(function () {
        s.a++;
      });
      s.a++;
    });
  });
  expect(result.current).toEqual(3);
  expect(result.all).toHaveLength(2);
});
test('merge synchronous context after async', /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee9() {
  var state, _renderHook8, result;

  return _regenerator.default.wrap(function _callee9$(_context9) {
    while (1) {
      switch (_context9.prev = _context9.next) {
        case 0:
          state = (0, _index.define)();
          state.setup({
            a: 1
          });
          _renderHook8 = (0, _reactHooks.renderHook)(function () {
            return state.use(function (s) {
              return s.a;
            });
          }), result = _renderHook8.result;
          _context9.next = 5;
          return (0, _reactHooks.act)( /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee8() {
            return _regenerator.default.wrap(function _callee8$(_context8) {
              while (1) {
                switch (_context8.prev = _context8.next) {
                  case 0:
                    _context8.next = 2;
                    return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee7(ctx) {
                      var s;
                      return _regenerator.default.wrap(function _callee7$(_context7) {
                        while (1) {
                          switch (_context7.prev = _context7.next) {
                            case 0:
                              ctx.state.a = 2;
                              _context7.next = 3;
                              return wait(100).then(function () {
                                return Promise.resolve(100);
                              });

                            case 3:
                              ctx.state.a = _context7.sent;
                              s = ctx.state;
                              state.update(function () {
                                s.a++;
                              });
                              s.a++;

                            case 7:
                            case "end":
                              return _context7.stop();
                          }
                        }
                      }, _callee7);
                    }));

                  case 2:
                  case "end":
                    return _context8.stop();
                }
              }
            }, _callee8);
          })));

        case 5:
          expect(result.current).toEqual(102);
          expect(result.all).toHaveLength(3);

        case 7:
        case "end":
          return _context9.stop();
      }
    }
  }, _callee9);
})));
test('nested async update', /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee13() {
  var state, _renderHook9, result;

  return _regenerator.default.wrap(function _callee13$(_context13) {
    while (1) {
      switch (_context13.prev = _context13.next) {
        case 0:
          state = (0, _index.define)();
          state.setup({
            a: 1
          });
          _renderHook9 = (0, _reactHooks.renderHook)(function () {
            return state.use(function (s) {
              return s.a;
            });
          }), result = _renderHook9.result;
          _context13.next = 5;
          return (0, _reactHooks.act)( /*#__PURE__*/(0, _asyncToGenerator2.default)( /*#__PURE__*/_regenerator.default.mark(function _callee12() {
            return _regenerator.default.wrap(function _callee12$(_context12) {
              while (1) {
                switch (_context12.prev = _context12.next) {
                  case 0:
                    _context12.next = 2;
                    return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee11(ctx) {
                      return _regenerator.default.wrap(function _callee11$(_context11) {
                        while (1) {
                          switch (_context11.prev = _context11.next) {
                            case 0:
                              ctx.state.a++;
                              _context11.next = 3;
                              return wait(100).then(function () {
                                return ctx.state.a + 1;
                              });

                            case 3:
                              ctx.state.a = _context11.sent;
                              _context11.next = 6;
                              return state.update( /*#__PURE__*/_regenerator.default.mark(function _callee10(ctx) {
                                return _regenerator.default.wrap(function _callee10$(_context10) {
                                  while (1) {
                                    switch (_context10.prev = _context10.next) {
                                      case 0:
                                        ctx.state.a++;
                                        _context10.next = 3;
                                        return wait(100).then(function () {
                                          return ctx.state.a + 1;
                                        });

                                      case 3:
                                        ctx.state.a = _context10.sent;
                                        state.update(function (ctx) {
                                          ctx.state.a++;
                                        });

                                      case 5:
                                      case "end":
                                        return _context10.stop();
                                    }
                                  }
                                }, _callee10);
                              }));

                            case 6:
                            case "end":
                              return _context11.stop();
                          }
                        }
                      }, _callee11);
                    }));

                  case 2:
                  case "end":
                    return _context12.stop();
                }
              }
            }, _callee12);
          })));

        case 5:
          expect(result.all).toEqual([1, 2, 4, 6]);

        case 6:
        case "end":
          return _context13.stop();
      }
    }
  }, _callee13);
})));
test('revoked draft should raise error', function (done) {
  var state = (0, _index.define)();
  state.setup({
    a: 1
  });
  state.update(function (ctx) {
    var draft = ctx.state;
    draft.a++;
    setTimeout(function () {
      expect(function () {
        draft.a++;
      }).toThrow();
      done();
    }, 100);
  });
});

var wait = function wait(timeout) {
  return new Promise(function (resolve) {
    return setTimeout(resolve, timeout);
  });
};
